@@ -1,4 +1,6 @@
+from django.contrib.auth.models import AnonymousUser
 from django.http import HttpResponsePermanentRedirect, HttpResponseRedirect
+from django.utils.functional import cached_property
 from django.views.generic import TemplateView
 from django_context_decorator import context
 
@@ -22,6 +24,11 @@ class FeaturedView(EventPermissionRequired, TemplateView):
             .order_by("title")
         )
 
+    @context
+    @cached_property
+    def hide_visibility_warning(self):
+        return AnonymousUser().has_perm(self.permission_required, self.request.event)
+
     def dispatch(self, request, *args, **kwargs):
         can_see_featured = self.has_permission()
         can_schedule = request.user.has_perm("agenda.view_schedule", request.event)
