@@ -123,15 +123,14 @@ class ExporterView(EventPermissionRequired, ScheduleMixin, TemplateView):
         if "If-None-Match" in request.headers:
             if request.headers["If-None-Match"] == etag:
                 return HttpResponseNotModified()
-        response = HttpResponse(data, content_type=file_type)
-        response["ETag"] = etag
+        headers = {"ETag": etag}
         if file_type not in ["application/json", "text/xml"]:
-            response[
+            headers[
                 "Content-Disposition"
             ] = f'attachment; filename="{safe_filename(file_name)}"'
         if exporter.cors:
-            response["Access-Control-Allow-Origin"] = exporter.cors
-        return response
+            headers["Access-Control-Allow-Origin"] = exporter.cors
+        return HttpResponse(data, content_type=file_type, headers=headers)
 
 
 class ScheduleView(EventPermissionRequired, ScheduleMixin, TemplateView):
@@ -259,6 +258,10 @@ class ScheduleView(EventPermissionRequired, ScheduleMixin, TemplateView):
         return {"data": list(data)}
 
 
+class ScheduleNoJsView(ScheduleView):
+    template_name = "agenda/schedule_nojs.html"
+
+
 class ChangelogView(EventPermissionRequired, TemplateView):
     template_name = "agenda/changelog.html"
     permission_required = "agenda.view_schedule"
