@@ -32,7 +32,10 @@ class SpeakerViewSet(viewsets.ReadOnlyModelViewSet):
             and self.request.event.settings.show_schedule
         ):
             return SpeakerProfile.objects.filter(
-                user__submissions__slots__in=self.request.event.current_schedule.talks.all()
+                event=self.request.event,
+                user__submissions__pk__in=self.request.event.current_schedule.talks.all().values_list(
+                    "submission_id", flat=True
+                ),
             ).distinct()
         return SpeakerProfile.objects.none()
 
