@@ -14,10 +14,10 @@ from i18nfield.fields import I18nFormField, I18nTextarea
 from i18nfield.forms import I18nFormMixin, I18nModelForm
 
 from pretalx.common.css import validate_css
-from pretalx.common.forms.fields import IMAGE_EXTENSIONS, ExtensionFileField
+from pretalx.common.forms.fields import ImageField
 from pretalx.common.mixins.forms import ReadOnlyFlag
 from pretalx.common.phrases import phrases
-from pretalx.event.models.event import Event, Event_SettingsStore
+from pretalx.event.models.event import Event
 from pretalx.orga.forms.widgets import HeaderSelect, MultipleLanguagesWidget
 from pretalx.submission.models import ReviewPhase, ReviewScore, ReviewScoreCategory
 
@@ -35,25 +35,6 @@ class EventForm(ReadOnlyFlag, I18nModelForm):
             " default language instead."
         ),
     )
-    logo = ExtensionFileField(
-        required=False,
-        extensions=IMAGE_EXTENSIONS,
-        label=_("Header image"),
-        help_text=_(
-            "If you provide a header image, it will be displayed instead of your event's color and/or header pattern "
-            "on top of all event pages. It will be center-aligned, so when the window shrinks, the center parts will "
-            "continue to be displayed, and not stretched."
-        ),
-    )
-    header_image = ExtensionFileField(
-        required=False,
-        extensions=IMAGE_EXTENSIONS,
-        label=_("Header image"),
-        help_text=_(
-            "If you provide a logo image, we will by default not show your event's name and date in the page header. "
-            "We will show your logo in its full size if possible, scaled down to the full header width otherwise."
-        ),
-    )
     custom_css_text = forms.CharField(
         required=False,
         widget=forms.Textarea(),
@@ -187,6 +168,10 @@ class EventForm(ReadOnlyFlag, I18nModelForm):
             "landing_page_text",
             "featured_sessions_text",
         ]
+        field_classes = {
+            "logo": ImageField,
+            "header_image": ImageField,
+        }
         widgets = {
             "date_from": forms.DateInput(attrs={"class": "datepickerfield"}),
             "date_to": forms.DateInput(
@@ -279,20 +264,6 @@ class EventSettingsForm(ReadOnlyFlag, I18nFormMixin, HierarkeyForm):
             raise ValidationError(
                 _("Please do not choose the default domain as custom event domain.")
             )
-        known_domains = [
-            domain.lower()
-            for domain in set(
-                Event_SettingsStore.objects.filter(key="custom_domain")
-                .exclude(object=self.obj)
-                .values_list("value", flat=True)
-            )
-            if domain
-        ]
-        parsed_domains = [urlparse(domain).hostname for domain in known_domains]
-        if data in known_domains or data in parsed_domains:
-            raise ValidationError(
-                _("This domain is already in use for a different event.")
-            )
         if not data.startswith("https://"):
             data = data[len("http://") :] if data.startswith("http://") else data
             data = "https://" + data
@@ -309,11 +280,6 @@ class EventSettingsForm(ReadOnlyFlag, I18nFormMixin, HierarkeyForm):
 
 
 class MailSettingsForm(ReadOnlyFlag, I18nFormMixin, HierarkeyForm):
-    mail_from = forms.EmailField(
-        label=_("Sender address"),
-        help_text=_("Sender address for outgoing emails."),
-        required=False,
-    )
     mail_reply_to = forms.EmailField(
         label=_("Contact address"),
         help_text=_(
@@ -343,6 +309,11 @@ class MailSettingsForm(ReadOnlyFlag, I18nFormMixin, HierarkeyForm):
         ),
         required=False,
     )
+    mail_from = forms.EmailField(
+        label=_("Sender address"),
+        help_text=_("Sender address for outgoing emails."),
+        required=False,
+    )
     smtp_host = forms.CharField(label=_("Hostname"), required=False)
     smtp_port = forms.IntegerField(label=_("Port"), required=False)
     smtp_username = forms.CharField(label=_("Username"), required=False)
@@ -423,6 +394,12 @@ class ReviewSettingsForm(ReadOnlyFlag, I18nFormMixin, HierarkeyForm):
     review_text_mandatory = forms.BooleanField(
         label=_("Require a review text"), required=False
     )
+    review_score_aggregate = forms.ChoiceField(
+        label=_("Score aggregation method"),
+        required=True,
+        choices=(("median", _("Median")), ("mean", _("Average (mean)"))),
+        widget=forms.RadioSelect,
+    )
     review_help_text = I18nFormField(
         label=_("Help text for reviewers"),
         help_text=_(
@@ -573,6 +550,7 @@ class ReviewScoreCategoryForm(I18nModelForm):
         model = ReviewScoreCategory
         fields = (
             "name",
+            "is_independent",
             "weight",
             "required",
             "active",
