@@ -2,9 +2,11 @@ import datetime as dt
 import json
 
 from django import forms
+from django.conf import settings
 from django.utils.translation import gettext as _
 from django_scopes.forms import SafeModelChoiceField, SafeModelMultipleChoiceField
 
+from pretalx.common.forms.fields import ImageField
 from pretalx.common.mixins.forms import ReadOnlyFlag, RequestRequire
 from pretalx.orga.forms.widgets import TagWidget
 from pretalx.submission.models import Submission, SubmissionStates, SubmissionType
@@ -22,6 +24,8 @@ class SubmissionForm(ReadOnlyFlag, RequestRequire, forms.ModelForm):
                 initial[key] = (
                     previous_data.get(key) or getattr(instance, key, None) or ""
                 )
+                if hasattr(initial[key], "all"):  # Tags, for the moment
+                    initial[key] = initial[key].all()
             kwargs["initial"] = initial
         super().__init__(**kwargs)
         if "submission_type" in self.fields:
@@ -30,7 +34,7 @@ class SubmissionForm(ReadOnlyFlag, RequestRequire, forms.ModelForm):
             )
         if not self.event.tags.all().exists():
             self.fields.pop("tags", None)
-        else:
+        elif "tags" in self.fields:
             self.fields["tags"].queryset = self.event.tags.all()
             self.fields["tags"].required = False
 
@@ -96,6 +100,15 @@ class SubmissionForm(ReadOnlyFlag, RequestRequire, forms.ModelForm):
             self.fields.pop("track", None)
         elif "track" in self.fields:
             self.fields["track"].queryset = event.tracks.all()
+        if "content_locale" in self.fields:
+            if len(event.locales) == 1:
+                self.initial["content_locale"] = event.locales[0]
+                self.fields["content_locale"].widget = forms.HiddenInput()
+            else:
+                locale_names = dict(settings.LANGUAGES)
+                self.fields["content_locale"].choices = [
+                    (a, locale_names[a]) for a in event.locales
+                ]
 
     def save(self, *args, **kwargs):
         instance = super().save(*args, **kwargs)
@@ -147,6 +160,7 @@ class SubmissionForm(ReadOnlyFlag, RequestRequire, forms.ModelForm):
             "submission_type": SafeModelChoiceField,
             "tags": SafeModelMultipleChoiceField,
             "track": SafeModelChoiceField,
+            "image": ImageField,
         }
         request_require = {
             "title",
