@@ -473,12 +473,14 @@ class SubmissionList(EventPermissionRequired, Sortable, Filterable, ListView):
     def get_queryset(self):
         qs = (
             Submission.all_objects.filter(event=self.request.event)
-            .select_related("submission_type")
+            .select_related("submission_type", "event", "track")
+            .prefetch_related("speakers")
             .order_by("-id")
             .all()
         )
         qs = self.filter_queryset(qs)
         question = self.request.GET.get("question")
+        unanswered = self.request.GET.get("unanswered")
         answer = self.request.GET.get("answer")
         option = self.request.GET.get("answer__options")
         if question and (answer or option):
@@ -488,13 +490,18 @@ class SubmissionList(EventPermissionRequired, Sortable, Filterable, ListView):
                     question_id=question,
                     options__pk=option,
                 )
-            else:
+            elif answer:
                 answers = Answer.objects.filter(
                     submission_id=OuterRef("pk"),
                     question_id=question,
                     answer__exact=answer,
                 )
             qs = qs.annotate(has_answer=Exists(answers)).filter(has_answer=True)
+        elif question and unanswered:
+            answers = Answer.objects.filter(
+                question_id=question, submission_id=OuterRef("pk")
+            )
+            qs = qs.annotate(has_answer=Exists(answers)).filter(has_answer=False)
         if "state" not in self.request.GET:
             qs = qs.exclude(state="deleted")
         qs = self.sort_queryset(qs)
@@ -649,8 +656,8 @@ class SubmissionStats(PermissionRequired, TemplateView):
             )
         return json.dumps({"deadlines": deadlines})
 
-    @context
-    def submission_timeline_data(self):
+    @cached_property
+    def raw_submission_timeline_data(self):
         data = Counter(
             log.timestamp.astimezone(self.request.event.tz).date()
             for log in ActivityLog.objects.filter(
@@ -665,12 +672,27 @@ class SubmissionStats(PermissionRequired, TemplateView):
                 count=(max(dates) - min(dates)).days + 1,
                 dtstart=min(dates),
             )
-            return json.dumps(
+            return sorted(
                 [
                     {"x": date.isoformat(), "y": data.get(date.date(), 0)}
                     for date in date_range
-                ]
+                ],
+                key=lambda x: x["x"],
             )
+
+    @context
+    def submission_timeline_data(self):
+        if self.raw_submission_timeline_data:
+            return json.dumps(self.raw_submission_timeline_data)
+        return ""
+
+    @context
+    def total_submission_timeline_data(self):
+        if self.raw_submission_timeline_data:
+            result = [{"x": 0, "y": 0}]
+            for point in self.raw_submission_timeline_data:
+                result.append({"x": point["x"], "y": result[-1]["y"] + point["y"]})
+            return json.dumps(result[1:])
         return ""
 
     @context
@@ -725,7 +747,7 @@ class SubmissionStats(PermissionRequired, TemplateView):
     @context
     def talk_timeline_data(self):
         data = Counter(
-            log.timestamp.astimezone(self.request.event.tz).date()
+            log.timestamp.astimezone(self.request.event.tz).date().isoformat()
             for log in ActivityLog.objects.filter(
                 event=self.request.event,
                 action_type="pretalx.submission.create",
@@ -733,17 +755,11 @@ class SubmissionStats(PermissionRequired, TemplateView):
             if getattr(log.content_object, "state", None)
             in [SubmissionStates.ACCEPTED, SubmissionStates.CONFIRMED]
         )
-        dates = data.keys()
-        if len(dates) > 1:
-            date_range = rrule.rrule(
-                rrule.DAILY,
-                count=(max(dates) - min(dates)).days + 1,
-                dtstart=min(dates),
-            )
+        if len(data.keys()) > 1:
             return json.dumps(
                 [
-                    {"x": date.isoformat(), "y": data.get(date.date(), 0)}
-                    for date in date_range
+                    {"x": point["x"], "y": data.get(point["x"][:10], 0)}
+                    for point in self.raw_submission_timeline_data
                 ]
             )
         return ""
@@ -835,6 +851,7 @@ class TagDetail(PermissionRequired, ActionFromUrl, CreateOrUpdateView):
     template_name = "orga/submission/tag_form.html"
     permission_required = "orga.view_submissions"
     write_permission_required = "orga.edit_tags"
+    create_permission_required = "orga.add_tags"
 
     def get_success_url(self) -> str:
         return self.request.event.orga_urls.tags
