@@ -189,7 +189,7 @@ def draw_grid_for_day(day, col_width=20):
         return None
 
     global_start = day.get("first_start", min(talk.start for talk in talk_list))
-    global_end = day.get("last_end", max(talk.end for talk in talk_list))
+    global_end = day.get("last_end", max(talk.real_end for talk in talk_list))
     talks_by_room = {str(r["name"]): r["talks"] for r in day["rooms"]}
     cards_by_id = {talk.pk: talk_card(talk, col_width) for talk in talk_list}
     rooms = list(talks_by_room.keys())
